pub struct InputDescriptor {
pub id: String,
pub name: Option<String>,
pub purpose: Option<String>,
pub format: Option<HashMap<String, ClaimFormat>>,
pub constraints: Constraints,
}Expand description
Input Descriptors describe the information a Verifier requires from the Holder. All Input Descriptors MUST be satisfied, unless otherwise specified.
Fields
id: StringAn identifier that does not conflict with the id of any other Input Descriptor in the same Presentation Definition.
name: Option<String>If set, it SHOULD be a human-friendly name that describes what the target schema represents.
purpose: Option<String>If present, its value MUST describe the purpose for which the Claim’s data is being requested.
format: Option<HashMap<String, ClaimFormat>>If present, its MUST be an object with one or more properties matching
registered Claim Format Designations (e.g., jwt, jwt_vc, jwt_vp,
etc.). This property can be used to specifically constrain
submission of a single input to a subset of the top-level formats or
algorithms specified in the Presentation Definition.
constraints: ConstraintsContraints specify constraints on data values, and an explanation why a certain item or set of data is being requested.