pub struct RequestObjectRequest {
pub client_id: String,
pub id: String,
}Expand description
The Request Object Request is used (indirectly) by the Wallet to retrieve a previously generated Authorization Request Object.
The Wallet is sent a request_uri containing a unique URL pointing to the
Request Object. The URI has the form client_id/request/state_key.
Fields
client_id: StringThe ID of the Verifier to retrieve the Authorization Request Object for.
id: StringThe unique identifier of the the previously generated Request Object.