pub struct RequestObject {
pub response_type: ResponseType,
pub client_id: String,
pub redirect_uri: Option<String>,
pub response_mode: Option<String>,
pub response_uri: Option<String>,
pub scope: Option<String>,
pub nonce: String,
pub state: Option<String>,
pub presentation_definition: Kind<PresentationDefinition>,
pub client_id_scheme: Option<ClientIdScheme>,
pub client_metadata: Verifier,
}Expand description
Fields
response_type: ResponseTypeThe type of response expected from the Wallet (as Authorization Server).
If Response Type is:
- “
vp_token”: a VP Token is returned in an Authorization Response. - “
vp_token id_token” AND thescopeparameter contains “openid”: a VP Token and a Self-Issued ID Token are returned in an Authorization Response. - “
code”: a VP Token is returned in a Token Response.
The default Response Mode is “fragment”: response parameters are encoded
in the fragment added to the redirect_uri when redirecting back to the
Verifier.
client_id: StringThe Verifier ID. MUST be a valid URI.
redirect_uri: Option<String>The URI to redirect to the Verifier’s redirection endpoint as established during client registration.
response_mode: Option<String>While the response_type parameter informs the Authorization Server
(Wallet) of the desired authorization flow, the response_mode
parameter informs it of the mechanism to use when returning an
Authorization Response.
A Response Mode of “direct_post” allows the Wallet to send the
Authorization Response to an endpoint controlled by the Verifier as
an HTTPS POST request.
If not set, the default value is “fragment”.
Response parameters are returned using the “application/x-www-form-urlencoded” content type. The flow can end with an HTTPS POST request from the Wallet to the Verifier, or it can end with a redirect that follows the HTTPS POST request, if the Verifier responds with a redirect URI to the Wallet.
Response Mode “direct_post.jwt” causes the Wallet to send the
Authorization Response as an HTTPS POST request (as for
“direct_post”) except the Wallet sets a response parameter to a
JWT containing the Authorization Response. See JARM for more
detail.
response_uri: Option<String>OPTIONAL. MUST be set when the Response Mode “direct_post” is used.
The URI to which the Wallet MUST send the Authorization Response using
an HTTPS POST request as defined by the Response Mode
“direct_post”.
When response_uri is set, redirect_uri MUST NOT be set. If set when
Response Mode is “direct_post”, the Wallet MUST return an
“invalid_request” error.
Note: If the Client Identifier scheme redirect_uri is used in
conjunction with the Response Mode “direct_post”, and the
response_uri parameter is present, the client_id value MUST be
equal to the response_uri value.
scope: Option<String>The Wallet MAY allow Verifiers to request presentation of Verifiable Credentials by utilizing a pre-defined scope value. Defined in RFC6749.
nonce: StringThe nonce is used to securely bind the requested Verifiable Presentation(s) provided by the Wallet to the particular transaction. Returned in the VP’s Proof.challenge parameter.
state: Option<String>State is used to maintain state between the Authorization Request and subsequent callback from the Wallet (‘Authorization Server’).
presentation_definition: Kind<PresentationDefinition>The Presentation Definition
client_id_scheme: Option<ClientIdScheme>The client_id_scheme is used to specify how the Wallet should to
obtain and validate Verifier metadata. The following values indicate
how the Wallet should interpret the value of the client_id
parameter.
- If not set, the Wallet MUST behave as specified in RFC6749.
- If the same Client Identifier is used with different Client Identifier schemes, those occurences MUST be treated as different Verifiers. The Verifier needs to determine which Client Identifier schemes the Wallet supports prior to sending the Authorization Request in order to choose a supported scheme.
client_metadata: VerifierClient Metadata contains Verifier metadata values.
Implementations
Sourceimpl RequestObject
impl RequestObject
Sourcepub fn to_qrcode(&self, endpoint: &str) -> Result<String, Error>
pub fn to_qrcode(&self, endpoint: &str) -> Result<String, Error>
Generate qrcode for Request Object.
Use the endpoint parameter to specify the Wallet’s endpoint using deep
link or direct call format.
For example,
openid-vc://?request_uri=
or GET https://holder.wallet.io/authorize?Errors
Returns an Error::ServerError error if the Request Object cannot be
serialized.